Struct Iter
struct Iter<'a, K, V> { ... }
An iterator over the entries of an IndexMap.
This struct is created by the IndexMap::iter method.
See its documentation for more.
Implementations
impl<'a, K, V> Iter<'a, K, V>
fn as_slice(self: &Self) -> &'a Slice<K, V>Returns a slice of the remaining entries in the iterator.
impl<'a, K, V> Freeze for Iter<'a, K, V>
impl<'a, K, V> Iterator for Iter<'a, K, V>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn last(self: Self) -> Option<<Self as >::Item>fn collect<C>(self: Self) -> C where C: FromIterator<<Self as >::Item>
impl<'a, K, V> RefUnwindSafe for Iter<'a, K, V>
impl<'a, K, V> Send for Iter<'a, K, V>
impl<'a, K, V> Sync for Iter<'a, K, V>
impl<'a, K, V> Unpin for Iter<'a, K, V>
impl<'a, K, V> UnsafeUnpin for Iter<'a, K, V>
impl<'a, K, V> UnwindSafe for Iter<'a, K, V>
impl<I> IntoIterator for Iter<'a, K, V>
fn into_iter(self: Self) -> I
impl<K, V> Clone for Iter<'_, K, V>
fn clone(self: &Self) -> Self
impl<K, V> Default for Iter<'_, K, V>
fn default() -> Self
impl<K, V> DoubleEndedIterator for Iter<'_, K, V>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>
impl<K, V> ExactSizeIterator for Iter<'_, K, V>
fn len(self: &Self) -> usize
impl<K, V> FusedIterator for Iter<'_, K, V>
impl<K: fmt::Debug, V: fmt::Debug> Debug for Iter<'_, K, V>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Iter<'a, K, V>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Iter<'a, K, V>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Iter<'a, K, V>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Iter<'a, K, V>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Iter<'a, K, V>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Iter<'a, K, V>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Iter<'a, K, V>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Iter<'a, K, V>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Iter<'a, K, V>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>