Struct IterMut
struct IterMut<'a, K, V> { ... }
A mutable iterator over the entries of an IndexMap.
This struct is created by the IndexMap::iter_mut method.
See its documentation for more.
Implementations
impl<'a, K, V> IterMut<'a, K, V>
fn as_slice(self: &Self) -> &Slice<K, V>Returns a slice of the remaining entries in the iterator.
fn into_slice(self: Self) -> &'a mut Slice<K, V>Returns a mutable slice of the remaining entries in the iterator.
To avoid creating
&mutreferences that alias, this is forced to consume the iterator.
impl<'a, K, V> Freeze for IterMut<'a, K, V>
impl<'a, K, V> Iterator for IterMut<'a, K, V>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn last(self: Self) -> Option<<Self as >::Item>fn collect<C>(self: Self) -> C where C: FromIterator<<Self as >::Item>
impl<'a, K, V> RefUnwindSafe for IterMut<'a, K, V>
impl<'a, K, V> Send for IterMut<'a, K, V>
impl<'a, K, V> Sync for IterMut<'a, K, V>
impl<'a, K, V> Unpin for IterMut<'a, K, V>
impl<'a, K, V> UnsafeUnpin for IterMut<'a, K, V>
impl<'a, K, V> UnwindSafe for IterMut<'a, K, V>
impl<I> IntoIterator for IterMut<'a, K, V>
fn into_iter(self: Self) -> I
impl<K, V> Default for IterMut<'_, K, V>
fn default() -> Self
impl<K, V> DoubleEndedIterator for IterMut<'_, K, V>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>
impl<K, V> ExactSizeIterator for IterMut<'_, K, V>
fn len(self: &Self) -> usize
impl<K, V> FusedIterator for IterMut<'_, K, V>
impl<K: fmt::Debug, V: fmt::Debug> Debug for IterMut<'_, K, V>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for IterMut<'a, K, V>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for IterMut<'a, K, V>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for IterMut<'a, K, V>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for IterMut<'a, K, V>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for IterMut<'a, K, V>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for IterMut<'a, K, V>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for IterMut<'a, K, V>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>