Struct Keys

struct Keys<'a, K, V> { ... }

An iterator over the keys of an IndexMap.

This struct is created by the IndexMap::keys method. See its documentation for more.

Implementations

impl<'a, K, V> Freeze for Keys<'a, K, V>

impl<'a, K, V> Iterator for Keys<'a, K, V>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn count(self: Self) -> usize
fn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>
fn last(self: Self) -> Option<<Self as >::Item>
fn collect<C>(self: Self) -> C
where
    C: FromIterator<<Self as >::Item>

impl<'a, K, V> RefUnwindSafe for Keys<'a, K, V>

impl<'a, K, V> Send for Keys<'a, K, V>

impl<'a, K, V> Sync for Keys<'a, K, V>

impl<'a, K, V> Unpin for Keys<'a, K, V>

impl<'a, K, V> UnsafeUnpin for Keys<'a, K, V>

impl<'a, K, V> UnwindSafe for Keys<'a, K, V>

impl<I> IntoIterator for Keys<'a, K, V>

fn into_iter(self: Self) -> I

impl<K, V> Clone for Keys<'_, K, V>

fn clone(self: &Self) -> Self

impl<K, V> Default for Keys<'_, K, V>

fn default() -> Self

impl<K, V> DoubleEndedIterator for Keys<'_, K, V>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>
fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>

impl<K, V> ExactSizeIterator for Keys<'_, K, V>

fn len(self: &Self) -> usize

impl<K, V> FusedIterator for Keys<'_, K, V>

impl<K, V> Index for Keys<'_, K, V>

fn index(self: &Self, index: usize) -> &K

Returns a reference to the key at the supplied index.

Panics if index is out of bounds.

impl<K: fmt::Debug, V> Debug for Keys<'_, K, V>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Keys<'a, K, V>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Keys<'a, K, V>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Keys<'a, K, V>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Keys<'a, K, V>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Keys<'a, K, V>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Keys<'a, K, V>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Keys<'a, K, V>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Keys<'a, K, V>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Keys<'a, K, V>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>