Struct IntoIter
struct IntoIter<T> { ... }
An owning iterator over the items of an IndexSet.
This struct is created by the IndexSet::into_iter method
(provided by the IntoIterator trait). See its documentation for more.
Implementations
impl<T> IntoIter<T>
fn as_slice(self: &Self) -> &Slice<T>Returns a slice of the remaining entries in the iterator.
impl<I> IntoIterator for IntoIter<T>
fn into_iter(self: Self) -> I
impl<T> Any for IntoIter<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for IntoIter<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for IntoIter<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for IntoIter<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Default for IntoIter<T>
fn default() -> Self
impl<T> DoubleEndedIterator for IntoIter<T>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>
impl<T> ExactSizeIterator for IntoIter<T>
fn len(self: &Self) -> usize
impl<T> Freeze for IntoIter<T>
impl<T> From for IntoIter<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FusedIterator for IntoIter<T>
impl<T> Iterator for IntoIter<T>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn last(self: Self) -> Option<<Self as >::Item>fn collect<C>(self: Self) -> C where C: FromIterator<<Self as >::Item>
impl<T> RefUnwindSafe for IntoIter<T>
impl<T> Send for IntoIter<T>
impl<T> Sync for IntoIter<T>
impl<T> ToOwned for IntoIter<T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> Unpin for IntoIter<T>
impl<T> UnsafeUnpin for IntoIter<T>
impl<T> UnwindSafe for IntoIter<T>
impl<T, U> Into for IntoIter<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for IntoIter<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for IntoIter<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::clone::Clone> Clone for IntoIter<T>
fn clone(self: &Self) -> IntoIter<T>
impl<T: fmt::Debug> Debug for IntoIter<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result