Struct Iter
struct Iter<'a, T> { ... }
An iterator over the items of an IndexSet.
This struct is created by the IndexSet::iter method.
See its documentation for more.
Implementations
impl<'a, T> Iter<'a, T>
fn as_slice(self: &Self) -> &'a Slice<T>Returns a slice of the remaining entries in the iterator.
impl<'a, T> Freeze for Iter<'a, T>
impl<'a, T> Iterator for Iter<'a, T>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn last(self: Self) -> Option<<Self as >::Item>fn collect<C>(self: Self) -> C where C: FromIterator<<Self as >::Item>
impl<'a, T> RefUnwindSafe for Iter<'a, T>
impl<'a, T> Send for Iter<'a, T>
impl<'a, T> Sync for Iter<'a, T>
impl<'a, T> Unpin for Iter<'a, T>
impl<'a, T> UnsafeUnpin for Iter<'a, T>
impl<'a, T> UnwindSafe for Iter<'a, T>
impl<I> IntoIterator for Iter<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for Iter<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Iter<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Iter<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Clone for Iter<'_, T>
fn clone(self: &Self) -> Self
impl<T> CloneToUninit for Iter<'a, T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Default for Iter<'_, T>
fn default() -> Self
impl<T> DoubleEndedIterator for Iter<'_, T>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>
impl<T> ExactSizeIterator for Iter<'_, T>
fn len(self: &Self) -> usize
impl<T> From for Iter<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FusedIterator for Iter<'_, T>
impl<T> ToOwned for Iter<'a, T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Iter<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Iter<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Iter<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: fmt::Debug> Debug for Iter<'_, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result