Struct Drain
struct Drain<'a, K, V> { ... }
A draining iterator over the entries of an IndexMap.
This struct is created by the IndexMap::drain method.
See its documentation for more.
Implementations
impl<'a, K, V> Drain<'a, K, V>
fn as_slice(self: &Self) -> &Slice<K, V>Returns a slice of the remaining entries in the iterator.
impl<'a, K, V> Freeze for Drain<'a, K, V>
impl<'a, K, V> RefUnwindSafe for Drain<'a, K, V>
impl<'a, K, V> Send for Drain<'a, K, V>
impl<'a, K, V> Sync for Drain<'a, K, V>
impl<'a, K, V> Unpin for Drain<'a, K, V>
impl<'a, K, V> UnsafeUnpin for Drain<'a, K, V>
impl<'a, K, V> UnwindSafe for Drain<'a, K, V>
impl<I> IntoIterator for Drain<'a, K, V>
fn into_iter(self: Self) -> I
impl<K, V> DoubleEndedIterator for Drain<'_, K, V>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>
impl<K, V> ExactSizeIterator for Drain<'_, K, V>
fn len(self: &Self) -> usize
impl<K, V> FusedIterator for Drain<'_, K, V>
impl<K, V> Iterator for Drain<'_, K, V>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn last(self: Self) -> Option<<Self as >::Item>fn collect<C>(self: Self) -> C where C: FromIterator<<Self as >::Item>
impl<K: fmt::Debug, V: fmt::Debug> Debug for Drain<'_, K, V>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Drain<'a, K, V>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Drain<'a, K, V>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Drain<'a, K, V>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Drain<'a, K, V>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Drain<'a, K, V>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Drain<'a, K, V>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Drain<'a, K, V>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>