pub struct OccupiedEntry<'a, K, V> { /* private fields */ }Expand description
A view into an occupied entry in a IndexMap.
It is part of the Entry enum.
Implementations
Sourceimpl<'a, K, V> OccupiedEntry<'a, K, V>
impl<'a, K, V> OccupiedEntry<'a, K, V>
pub fn key(&self) -> &K
pub fn get(&self) -> &V
pub fn get_mut(&mut self) -> &mut V
pub fn into_mut(self) -> &'a mut V
Sourcepub fn swap_remove_entry(self) -> (K, V)
pub fn swap_remove_entry(self) -> (K, V)
Remove and return the key, value pair stored in the map for this entry
Like Vec::swap_remove, the pair is removed by swapping it with the
last element of the map and popping it off. This perturbs
the postion of what used to be the last element!
Computes in O(1) time (average).
Sourcepub fn shift_remove_entry(self) -> (K, V)
pub fn shift_remove_entry(self) -> (K, V)
Remove and return the key, value pair stored in the map for this entry
Like Vec::remove, the pair is removed by shifting all of the
elements that follow it, preserving their relative order.
This perturbs the index of all of those elements!
Computes in O(n) time (average).
Sourceimpl<K, V> OccupiedEntry<'_, K, V>
impl<K, V> OccupiedEntry<'_, K, V>
Sourcepub fn insert(&mut self, value: V) -> V
pub fn insert(&mut self, value: V) -> V
Sets the value of the entry to value, and returns the entry’s old value.
Sourcepub fn remove(self) -> V
pub fn remove(self) -> V
Remove the key, value pair stored in the map for this entry, and return the value.
NOTE: This is equivalent to .swap_remove().
Sourcepub fn swap_remove(self) -> V
pub fn swap_remove(self) -> V
Remove the key, value pair stored in the map for this entry, and return the value.
Like Vec::swap_remove, the pair is removed by swapping it with the
last element of the map and popping it off. This perturbs
the postion of what used to be the last element!
Computes in O(1) time (average).
Sourcepub fn shift_remove(self) -> V
pub fn shift_remove(self) -> V
Remove the key, value pair stored in the map for this entry, and return the value.
Like Vec::remove, the pair is removed by shifting all of the
elements that follow it, preserving their relative order.
This perturbs the index of all of those elements!
Computes in O(n) time (average).
Sourcepub fn remove_entry(self) -> (K, V)
pub fn remove_entry(self) -> (K, V)
Remove and return the key, value pair stored in the map for this entry
NOTE: This is equivalent to .swap_remove_entry().