Struct Difference
struct Difference<'a, T, S> { ... }
A lazy iterator producing elements in the difference of IndexSets.
This struct is created by the IndexSet::difference method.
See its documentation for more.
Implementations
impl<'a, T, S> Freeze for Difference<'a, T, S>
impl<'a, T, S> Iterator for Difference<'a, T, S>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<'a, T, S> RefUnwindSafe for Difference<'a, T, S>
impl<'a, T, S> Send for Difference<'a, T, S>
impl<'a, T, S> Sync for Difference<'a, T, S>
impl<'a, T, S> Unpin for Difference<'a, T, S>
impl<'a, T, S> UnsafeUnpin for Difference<'a, T, S>
impl<'a, T, S> UnwindSafe for Difference<'a, T, S>
impl<I> IntoIterator for Difference<'a, T, S>
fn into_iter(self: Self) -> I
impl<T> Any for Difference<'a, T, S>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Difference<'a, T, S>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Difference<'a, T, S>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Difference<'a, T, S>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Difference<'a, T, S>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Difference<'a, T, S>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, S> Clone for Difference<'_, T, S>
fn clone(self: &Self) -> Self
impl<T, S> Debug for Difference<'_, T, S>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T, S> DoubleEndedIterator for Difference<'_, T, S>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>
impl<T, S> FusedIterator for Difference<'_, T, S>
impl<T, U> Into for Difference<'a, T, S>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Difference<'a, T, S>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Difference<'a, T, S>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>