Struct Drain
struct Drain<'a, T> { ... }
A draining iterator over the items of an IndexSet.
This struct is created by the IndexSet::drain method.
See its documentation for more.
Implementations
impl<'a, T> Drain<'a, T>
fn as_slice(self: &Self) -> &Slice<T>Returns a slice of the remaining entries in the iterator.
impl<'a, T> Freeze for Drain<'a, T>
impl<'a, T> RefUnwindSafe for Drain<'a, T>
impl<'a, T> Send for Drain<'a, T>
impl<'a, T> Sync for Drain<'a, T>
impl<'a, T> Unpin for Drain<'a, T>
impl<'a, T> UnsafeUnpin for Drain<'a, T>
impl<'a, T> UnwindSafe for Drain<'a, T>
impl<I> IntoIterator for Drain<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for Drain<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Drain<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Drain<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> DoubleEndedIterator for Drain<'_, T>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn nth_back(self: &mut Self, n: usize) -> Option<<Self as >::Item>
impl<T> ExactSizeIterator for Drain<'_, T>
fn len(self: &Self) -> usize
impl<T> From for Drain<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FusedIterator for Drain<'_, T>
impl<T> Iterator for Drain<'_, T>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn count(self: Self) -> usizefn nth(self: &mut Self, n: usize) -> Option<<Self as >::Item>fn last(self: Self) -> Option<<Self as >::Item>fn collect<C>(self: Self) -> C where C: FromIterator<<Self as >::Item>
impl<T, U> Into for Drain<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Drain<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Drain<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: fmt::Debug> Debug for Drain<'_, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result