Struct Union
struct Union<'a, T, S> { ... }
A lazy iterator producing elements in the union of IndexSets.
This struct is created by the IndexSet::union method.
See its documentation for more.
Implementations
impl<'a, T, S> Freeze for Union<'a, T, S>
impl<'a, T, S> Iterator for Union<'a, T, S>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn fold<B, F>(self: Self, init: B, f: F) -> B where F: FnMut(B, <Self as >::Item) -> B
impl<'a, T, S> RefUnwindSafe for Union<'a, T, S>
impl<'a, T, S> Send for Union<'a, T, S>
impl<'a, T, S> Sync for Union<'a, T, S>
impl<'a, T, S> Unpin for Union<'a, T, S>
impl<'a, T, S> UnsafeUnpin for Union<'a, T, S>
impl<'a, T, S> UnwindSafe for Union<'a, T, S>
impl<I> IntoIterator for Union<'a, T, S>
fn into_iter(self: Self) -> I
impl<T> Any for Union<'a, T, S>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Union<'a, T, S>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Union<'a, T, S>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Union<'a, T, S>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Union<'a, T, S>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Union<'a, T, S>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, S> Clone for Union<'_, T, S>
fn clone(self: &Self) -> Self
impl<T, S> Debug for Union<'_, T, S>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T, S> DoubleEndedIterator for Union<'_, T, S>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn rfold<B, F>(self: Self, init: B, f: F) -> B where F: FnMut(B, <Self as >::Item) -> B
impl<T, S> FusedIterator for Union<'_, T, S>
impl<T, U> Into for Union<'a, T, S>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Union<'a, T, S>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Union<'a, T, S>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>